<template>
    <div class="fullheight">
        <div style="display: flex">
            <el-form
                ref="searchForm"
                :model="searchForm"
                label-width="80px"
                class="searchTop"
            >
                <el-input
                    v-model="searchForm.applyAppName"
                    placeholder="请输入项目名称"
                    style="width: 220px; margin-right: 10px; margin-bottom: 5px"
                    clearable
                ></el-input>
                <dict-select
                    dictCode="cloud_type"
                    :hasDefaultOption="true"
                    clearable
                    placeholder="请选择所属云平台"
                    v-model="searchForm.cloudType"
                />
                <dict-select
                    dictCode="cloud_apply_status"
                    :hasDefaultOption="true"
                    clearable
                    placeholder="请选择审核状态"
                    v-model="searchForm.status"
                />
                <el-date-picker
                    v-model="searchForm.startTime"
                    type="date"
                    placeholder="请选择申请开始日期"
                    value-format="yyyy-MM-dd"
                >
                </el-date-picker>
                <el-date-picker
                    v-model="searchForm.endTime"
                    type="date"
                    placeholder="请选择申请结束日期"
                    value-format="yyyy-MM-dd"
                >
                </el-date-picker>
                <el-button size="small" @click="handleSearch" type="primary"
                    >查询</el-button
                >
                <el-button size="small" @click="handleReset" type="plain">重置</el-button>
            </el-form>
        </div>
        <ht-table
            @load="loadData"
            :data="tabelData"
            :pageResult="pageResult"
            :selection="true"
            :show-export="false"
            :show-custom-column="false"
            ref="htTable"
            @row-dblclick="handleEdit"
            :default-sorter="[{direction: 'DESC', property: 'id_'}]"
        >
            <template v-slot:toolbar>
                <div style="display: flex">
                    <el-button
                        type="primary"
                        size="small"
                        @click="handleAdd"
                        icon="el-icon-plus"
                        >添加</el-button
                    >
                    <ht-delete-button
                        url="${form}/bizCloudApply/v1/?"
                        :htTable="$refs.htTable"
                        >删除</ht-delete-button
                    >
                </div>
            </template>
            <template>
                <ht-table-column
                    prop="applyAppName"
                    width="260"
                    label="应用系统名称"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="cloudType"
                    label="资源所属云平台"
                    width="160"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                    <template slot-scope="{row}">
                        <el-tag v-if="row.cloudType">
                            {{ getDictName('cloud_type', row.cloudType) }}
                        </el-tag>
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="applyCode"
                    label="申请编号"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                />
                <ht-table-column
                    prop="applyUnitName"
                    label="单位名称"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                />
                <ht-table-column
                    prop="applyDate"
                    label="申请时间"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                    width="180"
                />
                <ht-table-column
                    prop="status"
                    label="状态"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                    width="100"
                >
                    <template slot-scope="{row}">
                        <el-tag v-if="row.status || row.status === 0">
                            {{ getDictName('cloud_apply_status', row.status) }}
                        </el-tag>
                    </template>
                </ht-table-column>
                <ht-table-column label="操作">
                    <template v-slot="{row}">
                        <el-dropdown
                            size="mini"
                            split-button
                            @command="handleCommand"
                            @click="handleCommand({row, command: 'handleDetails'})"
                        >
                            <span>
                                <i class="el-icon-view" style="margin-right: 5px"></i>
                                查看申请表
                            </span>
                            <el-dropdown-menu slot="dropdown">
                                <el-dropdown-item
                                    icon="el-icon-thumb"
                                    v-if="row.status === 0 || row.status === 20"
                                    :command="{
                                        row,
                                        command: 'startFlow',
                                    }"
                                    >发起审核</el-dropdown-item
                                >
                                <el-dropdown-item
                                    icon="el-icon-tickets"
                                    :command="{
                                        row,
                                        command: 'processRecord',
                                    }"
                                    >流程日志</el-dropdown-item
                                >
                                <el-dropdown-item
                                    icon="el-icon-download"
                                    :command="{
                                        row,
                                        command: 'export',
                                    }"
                                    >申请表导出</el-dropdown-item
                                >
                                <el-dropdown-item
                                    icon="el-icon-delete"
                                    v-if="row.status === 0"
                                    :command="{
                                        row,
                                        command: 'handleDelete',
                                    }"
                                    >删除</el-dropdown-item
                                >
                            </el-dropdown-menu>
                        </el-dropdown>
                    </template>
                </ht-table-column>
            </template>
        </ht-table>
        <applyForm ref="applyForm" @reload="handleReload" />
        <applyApproval ref="applyApproval" @close="handleReload" />
        <applyRecord ref="applyRecord" />
    </div>
</template>
<script>
import applyForm from './components/applyForm.vue'
import applyApproval from './components/applyApproval.vue'
import applyRecord from './components/applyRecord.vue'
import api from './js/api.js'
export default {
    name: 'resourceApply',
    components: {applyForm, applyApproval, applyRecord},
    data() {
        return {
            searchForm: {},
            tabelData: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
        }
    },

    methods: {
        handleSearch() {
            this.pageResult.page = 1
            this.loadData()
        },
        handleReset() {
            this.searchForm = {}
            this.pageResult.page = 1
            this.loadData()
        },
        loadData(params, cb) {
            let data = {
                pageBean: this.pageResult,
                querys: this.formatQuery(),
            }
            this.$http
                .post('${form}/bizCloudApply/v1/query', data)
                .then((res) => {
                    this.tabelData = res.data.rows
                    this.pageResult = {
                        page: res.data.page,
                        pageSize: res.data.pageSize,
                        total: res.data.total,
                    }
                })
                .finally(() => {
                    if (cb) {
                        cb()
                    }
                })
        },
        formatQuery() {
            let querys = []
            for (let key in this.searchForm) {
                if (this.searchForm[key] !== null) {
                    let operation,
                        property = key

                    switch (key) {
                        case 'applyAppName':
                            operation = 'LIKE'
                            break
                        case 'startTime':
                            operation = 'GREAT_EQUAL'
                            property = 'applyDate'
                            break
                        case 'endTime':
                            operation = 'LESS_EQUAL'
                            property = 'applyDate'
                            break
                        default:
                            operation = 'EQUAL'
                            break
                    }
                    querys.push({
                        group: 'main',
                        operation,
                        parentGroup: '',
                        property,
                        relation: 'AND',
                        value: this.searchForm[key],
                    })
                }
            }
            return querys
        },
        handleEdit(row) {
            this.$nextTick(() => {
                this.$refs.applyForm.handleOpen('apply', 'edit', row)
            })
        },
        handleAdd() {
            this.$nextTick(() => {
                this.$refs.applyForm.handleOpen('apply', 'add')
            })
        },
        handleReload() {
            this.loadData()
        },
        handleCommand(params) {
            if (params.command == 'handleDetails') {
                this.handleEdit(params.row)
            } else if (params.command == 'handleDelete') {
                this.$confirm('确定删除吗？', '提示', {
                    confirmButtonText: '确定',
                    cancelButtonText: '取消',
                    type: 'warning',
                }).then(() => {
                    this.$http
                        .remove('${form}/bizCloudApply/v1/?ids=' + params.row.id)
                        .then((res) => {
                            this.$refs.htTable.load()
                            if (res.state) {
                                this.$message({
                                    message: '删除成功',
                                    type: 'success',
                                })
                            } else {
                                this.$message({
                                    message: res.message,
                                    type: 'warning',
                                })
                            }
                        })
                        .finally(() => {
                            this.loadData()
                        })
                })
            } else if (params.command == 'processRecord') {
                this.$refs.applyRecord.handleOpen(params.row)
            } else if (params.command == 'startFlow') {
                this.$nextTick(() => {
                    this.$refs.applyApproval.handleOpen('start', params.row.id)
                })
            } else if (params.command == 'export') {
                api.downloadApply(params.row.id)
                    .then((res) => {
                        this.$message.success('导出成功')
                    })
                    .catch((err) => {
                        this.$message.warning(err)
                    })
            }
        },
    },
}
</script>

<style lang="scss" scoped>
.fullheight {
    padding: 10px;
    position: relative;
}
</style>